@@ -4,7 +4,6 @@ import difflib
 import os
 import shutil
 from collections import UserDict
-from dataclasses import dataclass
 from pathlib import Path
 from types import SimpleNamespace
 from typing import Any, Callable, Dict, List
@@ -13,28 +12,23 @@ import astropy.units as u
 from astropy.coordinates import EarthLocation
 from tomlkit.toml_file import TOMLFile
 
-from neclib import logger
+from . import EnvVarName, get_logger
+from .utils import ValueRange
 
-
-@dataclass
-class EnvVarName:
-    necst_root: str = "NECST_ROOT"
-    ros2_ws: str = "ROS2_WS"
-    domain_id: str = "ROS_DOMAIN_ID"
-    record_root: str = "NECST_RECORD_ROOT"
+logger = get_logger(__name__)
 
 
 class _ConfigParsers(UserDict):
-    def __missing__(self, key: str) -> Any:
+    def __missing__(self, key: str) -> Callable[[Any], Any]:
         if key in self.keys():
             return self[key]
-        similar_keys = difflib.get_close_matches(key.lower(), self.keys())
+        similar_keys = difflib.get_close_matches(key.lower(), self.keys(), cutoff=0.85)
         if similar_keys:
             logger.info(
                 f"Parser for '{key}' not found, instead using raw value. "
                 f"Similarly named parameters : {similar_keys}"
             )
-        return lambda x: getattr(x, "value", x)
+        return lambda x: x
 
 
 class Configuration:
@@ -76,7 +70,7 @@ class Configuration:
 
         def _prettify(key: str):
             value = self.__dict__.get(key, None)
-            return f"    {key:{length+2}s}{value!r}    ({type(value).__name__})"
+            return f"    {key:{length+2}s}{value!s}    ({type(value).__name__})"
 
         _parameters = "\n".join([_prettify(k) for k in self.__parameters])
         return f"NECST configuration\n{_parameters}"
@@ -84,7 +78,7 @@ class Configuration:
     def __str__(self) -> str:
         def _format(key: str):
             value = self.__dict__[key]
-            return f"{key}={value!r}"
+            return f"{key}={value!s}"
 
         _parameters = ", ".join([_format(k) for k in self.__parameters])
         return f"Configuration({_parameters})"
@@ -118,15 +112,19 @@ class Configuration:
             "observatory": str,
             "location": lambda x: EarthLocation(**x),
             "simulator": bool,
-            "record_root": Path,
+            "alert_interval_sec": float,
             "antenna_pid_param_az": list,
             "antenna_pid_param_el": list,
-            "antenna_drive_range_az": lambda x: list(map(u.Quantity, x)),
-            "antenna_drive_range_el": lambda x: list(map(u.Quantity, x)),
-            "antenna_drive_warning_limit_az": lambda x: list(map(u.Quantity, x)),
-            "antenna_drive_warning_limit_el": lambda x: list(map(u.Quantity, x)),
-            "antenna_drive_critical_limit_az": lambda x: list(map(u.Quantity, x)),
-            "antenna_drive_critical_limit_el": lambda x: list(map(u.Quantity, x)),
+            "antenna_drive_range_az": lambda x: ValueRange(*map(u.Quantity, x)),
+            "antenna_drive_range_el": lambda x: ValueRange(*map(u.Quantity, x)),
+            "antenna_drive_warning_limit_az": lambda x: ValueRange(*map(u.Quantity, x)),
+            "antenna_drive_warning_limit_el": lambda x: ValueRange(*map(u.Quantity, x)),
+            "antenna_drive_critical_limit_az": lambda x: ValueRange(
+                *map(u.Quantity, x)
+            ),
+            "antenna_drive_critical_limit_el": lambda x: ValueRange(
+                *map(u.Quantity, x)
+            ),
             "antenna_pointing_accuracy": u.Quantity,
             "antenna_pointing_parameter_path": lambda x: self.__dotnecst / Path(x),
             "antenna_max_acceleration_az": u.Quantity,
@@ -137,15 +135,15 @@ class Configuration:
             "antenna_speed_to_pulse_factor_el": u.Quantity,
             "antenna_command_frequency": int,
             "antenna_command_offset_sec": float,
-            "antenna_encoder_port_az": str,
-            "antenna_encoder_port_el": str,
             "ros_service_timeout_sec": float,
             "ros_communication_deadline_sec": float,
+            "ros_logging_interval_sec": float,
+            "ros_topic_scan_interval_sec": float,
         }
         return _ConfigParsers(_parsers)
 
     def __parse(self) -> List[str]:
-        raw_config = TOMLFile(self.__config_path).read().value
+        raw_config = TOMLFile(self.__config_path).read().unwrap()
         parser = self.__get_parser()
         for k, v in raw_config.items():
             setattr(self, k, parser[k](v))
@@ -157,7 +155,7 @@ class Configuration:
             candidates.insert(0, Path(os.environ[EnvVarName.necst_root]))
 
         for path in candidates:
-            config_path = path / "config.toml"
+            config_path = path if path.is_file() else path / "config.toml"
             if config_path.exists():
                 logger.info(f"Imported configuration file '{config_path}'")
                 return config_path
